@@ -2,7 +2,9 @@
 automua™ is a trademark of "Gaspard d'Hautefeuille" and may not be used 
 by third parties without the prior written permission of the author.
 
-Copyright © 2022 Gaspard d'Hautefeuille: bug fix JSON upload, replace SSL by TLS
+Copyright © 2022 Gaspard d'Hautefeuille: replacing SSL by TLS
+Gradual migration to sqlalchemy 2.0 new ORM usage (deprecating the legacy Query API).
+
 Copyright © 2019-2022 Ralph Seichter
 
 This file is part of automua.
@@ -23,17 +25,11 @@ along with automua. If not, see <https://www.gnu.org/licenses/>.
 import sys
 from typing import Optional
 
-from automua import PLACEHOLDER_ADDRESS
-from automua import log
-from automua.model import Davserver
-from automua.model import Domain
-from automua.model import Ldapserver
-from automua.model import Provider
-from automua.model import Server
-from automua.model import db
-from automua.util import from_dict
-from automua.util import from_environ
-from automua.util import unique
+from sqlalchemy import func, select
+
+from automua import PLACEHOLDER_ADDRESS, log
+from automua.model import Davserver, Domain, Ldapserver, Provider, Server, db
+from automua.util import from_dict, from_environ, unique
 
 LDAP_BIND_PASSWORD = from_environ('LDAP_BIND_PASSWORD')
 LDAP_BIND_USER = from_environ('LDAP_BIND_USER')
@@ -124,11 +120,11 @@ def populate_with_example_data():
 def populate_with_dict(config: dict) -> None:
     name: str = config['provider']
     short_name = name.split(' ')[0]
-    pid = Provider.query.count()+1
+    pid = db.session.scalar(select(func.count()).select_from(Provider)) + 1
     provider = Provider(id=pid, name=name, short_name=short_name)
     db.session.add(provider)
     domains = []
-    did = Domain.query.count()+1
+    did = db.session.scalar(select(func.count()).select_from(Domain)) + 1
     for domain in config['domains']:
         domains.append(Domain(id=did, name=domain, provider=provider))
         did += 1
@@ -137,7 +133,7 @@ def populate_with_dict(config: dict) -> None:
         return
     db.session.add_all(domains)
     servers = []
-    sid = Server.query.count()+1
+    sid = db.session.scalar(select(func.count()).select_from(Server)) + 1
     for server in config['servers']:
         name = server['name']
         type_ = server['type']
